Improve this doc

# Error: $parse:isecwindow
Referencing Window object in Expression

    Referencing the Window in Angular expressions is disallowed! Expression: {0}

## Description

Occurs when an expression attempts to access a Window object.

AngularJS restricts access to the Window object from within expressions since it's a known way to execute arbitrary Javascript code.

This check is only performed on object index and function calls in Angular expressions. These are places that are harder for the developer to guard. Dotted member access (such as a.b.c) does not perform this check - it's up to the developer to not expose such sensitive and powerful objects directly on the scope chain.

To resolve this error, avoid Window access.